<?php
// Register a icon box block for Gutenberg.
add_filter( 'rwmb_meta_boxes', function( $meta_boxes ) {
	$meta_boxes[] = [
		'title' => esc_html__('Icon Box', 'campoal-tapo'),
		'id'    => 'icon-box',
		'type'  => 'block', // Important.
		'mode' 	=> 'edit',
		// 'icon'  => 'awards', // Or you can set a custom SVG if you don't like Dashicons
		'icon'  => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 448 512"><!-- Font Awesome Pro 5.15.4 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license (Commercial License) --><defs><style>.fa-secondary{opacity:.4}</style></defs><path d="M400 32H48A48 48 0 0 0 0 80v352a48 48 0 0 0 48 48h352a48 48 0 0 0 48-48V80a48 48 0 0 0-48-48zm-176 86a42 42 0 1 1-42 42 42 42 0 0 1 42-42zm56 254a12 12 0 0 1-12 12h-88a12 12 0 0 1-12-12v-24a12 12 0 0 1 12-12h12v-64h-12a12 12 0 0 1-12-12v-24a12 12 0 0 1 12-12h64a12 12 0 0 1 12 12v100h12a12 12 0 0 1 12 12z" class="fa-secondary"/><path d="M224 202a42 42 0 1 0-42-42 42 42 0 0 0 42 42zm44 134h-12V236a12 12 0 0 0-12-12h-64a12 12 0 0 0-12 12v24a12 12 0 0 0 12 12h12v64h-12a12 12 0 0 0-12 12v24a12 12 0 0 0 12 12h88a12 12 0 0 0 12-12v-24a12 12 0 0 0-12-12z" class="fa-primary"/></svg>',
		'category' => 'campoal',
		'context' => 'side', // The block settings will be available on the right sidebar.
		'supports' => [
			'align' => ['wide', 'full'],
		],
		// 'render_callback' => 'conikal_featured_posts_shortcode',
		'render_template' => plugin_dir_path( __FILE__ ) . 'template.php', // The PHP template that renders the block.
		// 'enqueue_style'   => plugin_dir_path( __FILE__ ) . 'style.css', // CSS file for the block.

		// Now register the block fields.
		'fields' => [
			[
				'type' => 'select',
				'id'   => 'icon_type',
				'name' => esc_html__('Icon Type', 'campoal-tapo'),
				'options' => array(
					'icon' 		=> esc_html__('Icon font', 'campoal-tapo'),
					'image' 	=> esc_html__('Icon image', 'campoal-tapo'),
				),
				'placeholder'   => esc_html__('Default', 'campoal-tapo'),
			],
			[
				'type' 			=> 'text',
				'id'   			=> 'icon',
				'name' 			=> esc_html__('Icon name or Icon URL', 'campoal-tapo'),
				'placeholder'   => esc_html__('Enter a icon name or icon url', 'campoal-tapo'),
			],
			[
				'type' 			=> 'number',
				'id'   			=> 'size',
				'name' 			=> esc_html__('Icon size', 'campoal-tapo'),
				'placeholder'   => esc_html__('Enter a icon size in pixel', 'campoal-tapo'),
			],
			[
				'name'             => esc_html__('Image', 'campoal-tapo'),
    			'id'               => 'icon_image',
    			'type'             => 'image_upload',
				'force_delete'     => true,
			],
			[
				'type' 			=> 'number',
				'id'   			=> 'img_size',
				'name' 			=> esc_html__('Image size (eg. 200x200)', 'campoal-tapo'),
				'placeholder'   => esc_html__('Example: "full" or "200x200"', 'campoal-tapo'),
			],
			[
				'type' 			=> 'text',
				'id'   			=> 'title',
				'name' 			=> esc_html__('Title', 'campoal-tapo'),
				'placeholder'   => esc_html__('Enter a title', 'campoal-tapo'),
			],
			[
				'type' 			=> 'textarea',
				'id'   			=> 'content',
				'raw'     		=> false,
				'name' 			=> esc_html__('Description', 'campoal-tapo'),
				'placeholder'   => esc_html__('Enter text below heading', 'campoal-tapo'),
			],
			[
				'type' 			=> 'button_group',
				'id'   			=> 'align',
				'name' 			=> esc_html__('Alignment', 'campoal-tapo'),
				'options' => array(
					'left' 		=> '<span class="dashicons dashicons-editor-alignleft"></span>',
					'center' 	=> '<span class="dashicons dashicons-editor-aligncenter"></span>',
					'right' 	=> '<span class="dashicons dashicons-editor-alignright"></span>',
				),
				'inline'   		=> true,
			],
			[
				'type' => 'select',
				'id'   => 'style',
				'name' => esc_html__('Style', 'campoal-tapo'),
				'options' => array(
					'vertical' 		=> esc_html__('Vertical', 'campoal-tapo'),
					'horizontal' 	=> esc_html__('Horizontal', 'campoal-tapo'),
				),
				'placeholder'   => esc_html__('Default', 'campoal-tapo'),
			],
			[
				'type' => 'select',
				'id'   => 'type',
				'name' => esc_html__('Box type', 'campoal-tapo'),
				'options' => array(
					'normal' 	=> esc_html__('Normal', 'campoal-tapo'),
					'raised' 	=> esc_html__('Raise', 'campoal-tapo'),
					'stacked' 	=> esc_html__('Stack', 'campoal-tapo'),
					'piled' 	=> esc_html__('Pile', 'campoal-tapo'),
					'circular' 	=> esc_html__('Circular', 'campoal-tapo'),
					'compact' 	=> esc_html__('Compact', 'campoal-tapo'),
					'vertical' 	=> esc_html__('Vertical', 'campoal-tapo'),
					'basic' 	=> esc_html__('Basic', 'campoal-tapo'),
				),
				'placeholder'   => esc_html__('Default', 'campoal-tapo'),
			],
			[
				'type' => 'select',
				'id'   => 'heading_size',
				'name' => esc_html__('Heading size', 'campoal-tapo'),
				'options' => array(
					'normal' 	=> esc_html__('Normal', 'campoal-tapo'),
					'tiny' 		=> esc_html__('Tiny', 'campoal-tapo'),
					'small' 	=> esc_html__('Small', 'campoal-tapo'),
					'medium' 	=> esc_html__('Medium', 'campoal-tapo'),
					'large' 	=> esc_html__('Large', 'campoal-tapo'),
					'huge' 		=> esc_html__('Huge', 'campoal-tapo'),
				),
				'placeholder'   => esc_html__('Default', 'campoal-tapo'),
			],
			[
				'type' => 'select',
				'id'   => 'padding',
				'name' => esc_html__('Padding', 'campoal-tapo'),
				'options' => array(
					'no' 			=> esc_html__('No', 'campoal-tapo'),
					'padded' 		=> esc_html__('Padded', 'campoal-tapo'),
					'very padded' 	=> esc_html__('Very Padded', 'campoal-tapo'),
				),
				'placeholder'     	=> esc_html__('Default', 'campoal-tapo'),
			],
			[
				'type' 			=> 'text',
				'id'   			=> 'link',
				'name' 			=> esc_html__('Link', 'campoal-tapo'),
				'placeholder'   => esc_html__('Enter a url', 'campoal-tapo'),
			],
			[
				'type' => 'checkbox',
				'id'   => 'invert',
				'name' => esc_html__('Invert color', 'campoal-tapo'),
			],
			[
				'type' => 'color',
				'id'   => 'color',
				'name' => 'Background Color',
			],
			[
				'type' => 'color',
				'id'   => 'text_color',
				'name' => 'Text Color',
			],
		],
	];
	return $meta_boxes;
} );
