<?php
// Register a petitions block for Gutenberg.
add_filter( 'rwmb_meta_boxes', function( $meta_boxes ) {

	// get petition category
	$category_options = array();
	$categories =  get_terms( array(
		'taxonomy' => 'petition_category',
		'hide_empty' => false,
	) );

	foreach ($categories as $category) {
		$category_options[$category->term_id] = $category->name;
	}

	// get petition topcis
	$topics_options = array();
	$topics =  get_terms( array(
		'taxonomy' => 'petition_topics',
		'hide_empty' => false,
	) );

	foreach ($topics as $topic) {
		$topics_options[$topic->term_id] = $topic->name;
	}

	$meta_boxes[] = [
		'title' => esc_html__('Petitions', 'campoal-tapo'),
		'id'    => 'petitions',
		'type'  => 'block', // Important.
		'mode' 	=> 'edit',
		// 'icon'  => 'awards', // Or you can set a custom SVG if you don't like Dashicons
		'icon'  => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512"><!-- Font Awesome Pro 5.15.4 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license (Commercial License) --><defs><style>.fa-secondary{opacity:.4}</style></defs><path d="M458.38 234.79L351.83 288H433a396.85 396.85 0 0 1-30.46 47.12L255.73 384h101c-35.57 30.07-79.11 51.1-132.59 56.54a1130.32 1130.32 0 0 1-125.99 7.36h-.06L305 241a24 24 0 0 0-34-34L64 414c.08-62.81 4-100.05 7-126.44C96.44 38.2 460.21 3.56 512 0c-1.81 26.26-11.71 132.86-53.62 234.79z" class="fa-secondary"/><path d="M24 512a24 24 0 0 1-17-41l264-264a24 24 0 0 1 34 34L41 505a23.92 23.92 0 0 1-17 7z" class="fa-primary"/></svg>',
		'category' => 'campoal',
		'context' => 'side', // The block settings will be available on the right sidebar.
		'supports' => [
			'align' => ['wide', 'full'],
		],
		// 'render_callback' => 'conikal_featured_posts_shortcode',
		'render_template' => plugin_dir_path( __FILE__ ) . 'template.php', // The PHP template that renders the block.
		// 'enqueue_style'   => plugin_dir_path( __FILE__ ) . 'style.css', // CSS file for the block.

		// Now register the block fields.
		'fields' => [
			[
				'type' 			=> 'text',
				'id'   			=> 'title',
				'name' 			=> esc_html__('Section Title', 'campoal-tapo'),
				'placeholder'   => esc_html__('Enter a title', 'campoal-tapo'),
			],
			[
				'type' 			=> 'button_group',
				'id'   			=> 'title_alignment',
				'name' 			=> esc_html__('Title Alignment', 'campoal-tapo'),
				'options' => array(
					'left' 			=> '<span class="dashicons dashicons-editor-alignleft"></span>',
					'center' 		=> '<span class="dashicons dashicons-editor-aligncenter"></span>',
					'right' 		=> '<span class="dashicons dashicons-editor-alignright"></span>',
				),
				'inline'   => true,
			],
			[
				'type' => 'select',
				'id'   => 'type',
				'name' => esc_html__('Type', 'campoal-tapo'),
				'options' => array(
					'recent' 			=> esc_html__('Recent', 'campoal-tapo'),
					'featured' 			=> esc_html__('Featured', 'campoal-tapo'),
					'victory' 			=> esc_html__('Victory', 'campoal-tapo'),
					'victory_featured' 	=> esc_html__('Victory Featured', 'campoal-tapo'),
					'by_id' 			=> esc_html__('Petition by IDs', 'campoal-tapo'),
				),
				'placeholder'     => esc_html__('Default', 'campoal-tapo'),
			],
			[
				'type' => 'select',
				'id'   => 'style',
				'name' => esc_html__('Style', 'campoal-tapo'),
				'options' => array(
					'grid' 			=> esc_html__('Grid', 'campoal-tapo'),
					'list' 			=> esc_html__('List', 'campoal-tapo'),
				),
				'placeholder'     => esc_html__('Default', 'campoal-tapo'),
			],
			[
				'type' 			=> 'number',
				'id'   			=> 'show',
				'name' 			=> esc_html__('Show', 'campoal-tapo'),
				'placeholder'	=> esc_html__('Number of petitions display', 'campoal-tapo'),
			],
			[
				'type' => 'select',
				'id'   => 'column',
				'name' => esc_html__('Column', 'campoal-tapo'),
				'options' => array(
					'two' 	=> '2',
					'three' => '3',
					'four' 	=> '4',
				),
				'placeholder'     => esc_html__('Default', 'campoal-tapo'),
			],
			[
				'type' => 'select',
				'id'   => 'orderby',
				'name' => 'Order by',
				'options' => array(
					'none' 			=> esc_html__('None', 'campoal-tapo'),
					'views' 		=> esc_html__('Views', 'campoal-tapo'),
					'supporters' 	=> esc_html__('Supporters', 'campoal-tapo'),
					'ID' 			=> esc_html__('ID', 'campoal-tapo'),
					'author' 		=> esc_html__('Author', 'campoal-tapo'),
					'title' 		=> esc_html__('Title', 'campoal-tapo'),
					'name' 			=> esc_html__('Name', 'campoal-tapo'),
					'date' 			=> esc_html__('Date', 'campoal-tapo'),
					'modified' 		=> esc_html__('Modified', 'campoal-tapo'),
					'rand' 			=> esc_html__('Random', 'campoal-tapo'),
					'comment_count'	=> esc_html__('Comment count', 'campoal-tapo'),
				),
				'placeholder'     	=> esc_html__('Default', 'campoal-tapo'),
			],
			[
				'type' => 'select',
				'id'   => 'order',
				'name' => esc_html__('Order', 'campoal-tapo'),
				'options' => array(
					'ASC' 	=> esc_html__('Ascending', 'campoal-tapo'),
					'DESC' 	=> esc_html__('Descending', 'campoal-tapo'),
				),
				'placeholder'     => esc_html__('Default', 'campoal-tapo'),
			],
			[
				'type' 		=> 'select',
				'id'   		=> 'categories',
				'name' 		=> esc_html__('Categories', 'campoal-tapo'),
				'options' 	=> $category_options,
				'multiple'        => true,
				'select_all_none' => true,
				'placeholder'     => esc_html__('All', 'campoal-tapo'),
			],
			[
				'type' 		=> 'select',
				'id'   		=> 'topics',
				'name' 		=> esc_html__('Topics', 'campoal-tapo'),
				'options' 	=> $topics_options,
				'multiple'        => true,
				'select_all_none' => true,
				'placeholder'     => esc_html__('All', 'campoal-tapo'),
			],
			[
				'type' => 'checkbox',
				'id'   => 'carousel',
				'name' => esc_html__('Carousel', 'campoal-tapo'),
			],
			[
				'type' => 'checkbox',
				'id'   => 'hover',
				'name' => esc_html__('Shadow', 'campoal-tapo'),
			],
			[
				'type' 			=> 'text',
				'id'   			=> 'petition_ids',
				'name' 			=> esc_html__('Petition IDs', 'campoal-tapo'),
				'placeholder'   => esc_html__('Optional (separated by commas)', 'campoal-tapo'),
			],
		],
	];
	return $meta_boxes;
} );
