<?php
/**
 * @package WordPress
 * @subpackage Campoal Tapo
 */


/**
 * Function to add petition to bookmarks
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_add_to_bookmarks') ): 
    function conikal_add_to_bookmarks() {
        check_ajax_referer('bookmark_ajax_nonce', 'security');
        $post_id = isset($_POST['post_id']) ? sanitize_text_field($_POST['post_id']) : '';
        $user_id = isset($_POST['user_id']) ? sanitize_text_field($_POST['user_id']) : '';
        $type = isset($_POST['type']) ? sanitize_text_field($_POST['type']) : 'petition';

        $bookmarks_key = $type . '_bookmark';
        $bookmarks = get_user_meta($user_id, $bookmarks_key, true);
        if($bookmarks == '') {
            $bookmarks = array();
            delete_user_meta($user_id, $bookmarks_key);
            add_user_meta($user_id, $bookmarks_key, $bookmarks);
        }
        if(in_array($post_id, $bookmarks) === false) {
            array_push($bookmarks, $post_id);
            update_user_meta($user_id, $bookmarks_key, $bookmarks);
        }

        echo json_encode(array('status'=>true, 'bookmarks'=>$bookmarks));

        die();
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_add_to_bookmarks', 'conikal_add_to_bookmarks' );
add_action( 'wp_ajax_conikal_add_to_bookmarks', 'conikal_add_to_bookmarks' );


/**
 * Function to remove petition from bookmarks
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_remove_from_bookmarks') ): 
    function conikal_remove_from_bookmarks() {
        check_ajax_referer('bookmark_ajax_nonce', 'security');
        $post_id = isset($_POST['post_id']) ? sanitize_text_field($_POST['post_id']) : '';
        $user_id = isset($_POST['user_id']) ? sanitize_text_field($_POST['user_id']) : '';
        $type = isset($_POST['type']) ? sanitize_text_field($_POST['type']) : 'petition';

        $bookmarks_key = $type . '_bookmark';
        $bookmarks = get_user_meta($user_id, $bookmarks_key, true);
        if(in_array($post_id, $bookmarks)) {
            $bookmarks = array_diff($bookmarks, array($post_id));
            update_user_meta($user_id, $bookmarks_key, $bookmarks);
        }

        echo json_encode(array('status'=>true, 'bookmarks'=>$bookmarks));

        die();
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_remove_from_bookmarks', 'conikal_remove_from_bookmarks' );
add_action( 'wp_ajax_conikal_remove_from_bookmarks', 'conikal_remove_from_bookmarks' );