<?php
/**
 * @package WordPress
 * @subpackage Campoal Tapo
 */


/**
 * Add new citation of citation
 *
 * @since Campoal Tapo 1.5.6
 */
if( !function_exists('conikal_add_citation_petition') ): 
    function conikal_add_citation_petition() {
        check_ajax_referer('citation_ajax_nonce', 'security');
        global $campoal_options;
        $prefix = 'citation_';
        $review_citation          = isset($campoal_options['conikal_review_citation_field']) ? $campoal_options['conikal_review_citation_field'] : 0;

        $allowed_html = conikal_content_allowed_html();
        $user_id = isset($_POST['user_id']) ? sanitize_text_field($_POST['user_id']) : '';
        $post_id = isset($_POST['post_id']) ? sanitize_text_field($_POST['post_id']) : '';
        $citation_id = isset($_POST['citation_id']) ? sanitize_text_field($_POST['citation_id']) : '';
        $title = isset($_POST['title']) ? sanitize_text_field($_POST['title']) : '';
        $content = isset($_POST['content']) ? wp_kses($_POST['content'], $allowed_html) : '';
        $opinion = isset($_POST['opinion']) ? sanitize_text_field($_POST['opinion']) : 'yes';
        $reference = isset($_POST['reference']) ? sanitize_text_field($_POST['reference']) : '';
        $graph_title = isset($_POST['graph_title']) ? sanitize_text_field($_POST['graph_title']) : '';
        $graph_description = isset($_POST['graph_description']) ? sanitize_text_field($_POST['graph_description']) : '';
        $graph_image = isset($_POST['graph_image']) ? sanitize_text_field($_POST['graph_image']) : '';
        $graph_site = isset($_POST['graph_site']) ? sanitize_text_field($_POST['graph_site']) : '';
        $petition_id = isset($_POST['petition_id']) ? sanitize_text_field($_POST['petition_id']) : '';
        $gallery = isset($_POST['gallery']) ? sanitize_text_field($_POST['gallery']) : '';
        $video = isset($_POST['video']) ? sanitize_text_field($_POST['video']) : '';
        $thumb = isset($_POST['thumb']) ? sanitize_text_field($_POST['thumb']) : '';
        $thumb_small = isset($_POST['thumb_small']) ? sanitize_text_field($_POST['thumb_small']) : '';
        $attach_id = isset($_POST['attach']) ? sanitize_text_field($_POST['attach']) : '';

        if($review_citation == 0 || $citation_id != '' ||  user_can($user_id, 'administrator') || user_can($user_id, 'editor')) {
            $citation_status = 'publish';
        } else {
            $citation_status = 'pending';
        }

        $citation_arg = array(
            'post_title' => $title,
            'post_content' => $content,
            'post_type' => 'citation',
            'post_status' => $citation_status,
            'post_author' => $user_id
        );


        if ($citation_id != '') {
            $citation_arg['ID'] = $citation_id;
        } else {
            $citation_arg['post_status'] = $citation_status;
        }

        if($title == '') {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('Title field is mandatory.', 'campoal-tapo')));
            exit();
        }
        if($content == '' || strlen($content) < 10) {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('Content field is mandatory and minimum 10 characters.', 'campoal-tapo')));
            exit();
        }
        if($petition_id == '') {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('Petition id field is mandatory.', 'campoal-tapo')));
            exit();
        }
        
        if ($citation_id != '') {
            $citation = wp_update_post($citation_arg);
        } else {
            $citation = wp_insert_post($citation_arg);
            update_post_meta($citation, $prefix . 'opinion', $opinion);
        }

        update_post_meta($citation, $prefix . 'post_id', $petition_id);
        update_post_meta($citation, $prefix . 'reference', $reference);
        update_post_meta($citation, $prefix . 'reference_title', $graph_title);
        update_post_meta($citation, $prefix . 'reference_description', $graph_description);
        update_post_meta($citation, $prefix . 'reference_image', $graph_image);
        update_post_meta($citation, $prefix . 'reference_site', $graph_site);
        update_post_meta($citation, $prefix . 'gallery', $gallery);
        update_post_meta($citation, $prefix . 'video', $video);
        update_post_meta($citation, $prefix . 'thumb', $thumb);
        update_post_meta($citation, $prefix . 'thumb_small', $thumb_small);
        set_post_thumbnail( $citation, $attach_id );

        // send email notification for admin
        conikal_admin_citation_notification($petition_id, $citation, $user_id, $citation_id);

        // get link after submited citation
        $approve = get_post_status($citation);
        if ($approve == 'pending') {
            $petition_link = get_permalink($petition_id);
            if ($petition_link) {
                $citation_link = add_query_arg(array('action' => 'citation_pending'), $petition_link);
            }
        } else {
            $citation_link = get_permalink($citation);
            if ($citation_id != '') {
                $citation_link = add_query_arg(array('action' => 'citation_edited'), $citation_link);
            }
        }

        if($citation != 0) {
            $opinion_number = conikal_opinion_number_citation($petition_id, $opinion);

            echo json_encode(array('status' => true, 'ID' => $citation, 'link' => $citation_link, 'opinion_number' => $opinion_number, 'message'=>esc_html__('The citation was saved successfully.', 'campoal-tapo')));
            exit();
        } else {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('Something went wrong. The citation was not saved.', 'campoal-tapo')));
            exit();
        }

        die();
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_add_citation_petition', 'conikal_add_citation_petition' );
add_action( 'wp_ajax_conikal_add_citation_petition', 'conikal_add_citation_petition' );

/**
 * Set citation opinion number
 *
 * @since Campoal Tapo 1.5.6
 */
if( !function_exists('conikal_opinion_number_citation') ): 
    function conikal_opinion_number_citation($post_id, $opinion, $operator = 'plus') {
        $opinion_key_yes = 'petition_opinion_yes';
        $opinion_key_no = 'petition_opinion_no';
        $opinion_yes = get_post_meta($post_id, $opinion_key_yes, true);
        $opinion_no = get_post_meta($post_id, $opinion_key_no, true);

        if ($opinion == 'yes') {
            if ($opinion_yes == '') {
                delete_post_meta($post_id, $opinion_key_yes);
                update_post_meta($post_id, $opinion_key_yes, 0);
            }

            $opinion_number = ($operator == 'plus') ? intval($opinion_yes) + 1 : intval($opinion_yes) - 1;
            update_post_meta($post_id, $opinion_key_yes, $opinion_number);
        } else {
            if ($opinion_no == '') {
                delete_post_meta($post_id, $opinion_key_no);
                update_post_meta($post_id, $opinion_key_no, 0);
            }

            $opinion_number = ($operator == 'plus') ? intval($opinion_no) + 1 : intval($opinion_no) - 1;
            update_post_meta($post_id, $opinion_key_no, $opinion_number);
        }

        // calcular score
        $opinion_yes_number = get_post_meta($post_id, $opinion_key_yes, true);
        $opinion_no_number = get_post_meta($post_id, $opinion_key_no, true);
        if ((int)$opinion_yes_number != 0 || (int)$opinion_yes_number != 0) {
            $opinion_total = intval($opinion_yes_number) + intval($opinion_no_number);
            $fact_score = (intval($opinion_yes_number) / $opinion_total) * 100;
            $fact_score = round($fact_score);
        } else {
            $opinion_total = 0;
            $fact_score = 0;
        }

        $result = array('yes'   => (int)$opinion_yes_number,
                        'no'    => (int)$opinion_no_number,
                        'total' => (int)$opinion_total,
                        'percent' => $fact_score);

        return $result;
    }
endif;

/**
 * Get the citation of petition
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_citation_petition') ): 
    function conikal_citation_petition($post_id, $number = 0, $sort = 'DESC') {
        global $campoal_options;
        global $paged;

        $citations_per_page = isset($campoal_options['conikal_citations_per_page_field']) ? $campoal_options['conikal_citations_per_page_field'] : 5;

        $paged = (get_query_var('paged')) ? get_query_var('paged') : 1;
        $args = array(
            'posts_per_page' => $citations_per_page,
            'paged' => $paged,
            'post_type' => 'update',
            'post_status' => 'publish',
            'order'   => $sort,
        );

        $args['meta_query'] = array('relation' => 'AND');

        if($post_id != '') {
            array_push($args['meta_query'], array(
                'key'     => 'citation_post_id',
                'value'   => $post_id,
            ));
        }

        $query = new WP_Query($args);

        wp_reset_postdata();
        wp_reset_query(); 
        
        return $query;
    }
endif;


/**
 * Load more citation of petition
 *
 * @since Campoal Tapo 1.5.6
 */
if( !function_exists('conikal_load_citations_petition') ): 
    function conikal_load_citations_petition() {
        check_ajax_referer('citation_ajax_nonce', 'security');
        global $campoal_options;
        global $current_user;

        $citations_per_page = isset($campoal_options['conikal_citations_per_page_field']) ? $campoal_options['conikal_citations_per_page_field'] : 5;
        $page_dashboard_petition = isset($campoal_options['conikal_page_dashboard_petition_field']) ? $campoal_options['conikal_page_dashboard_petition_field'] : 0;
        $page_dashboard_petition = $page_dashboard_petition ? get_permalink($page_dashboard_petition) : '';
        $sort = isset($_GET['sort']) ? sanitize_text_field($_GET['sort']) : 'newest';
        $citation_post_id = isset($_POST['post_id']) ? sanitize_text_field($_POST['post_id']) : '';
        $user_id = isset($_POST['user_id']) ? sanitize_text_field($_POST['user_id']) : '';
        $offset = isset($_POST['offset']) ? sanitize_text_field($_POST['offset']) : 5;

        $post_type = get_post_type($citation_post_id);
        if ($post_type == 'citation') {
            $post_id = get_post_meta($citation_post_id, 'citation_post_id', true); 
        } else {
            $post_id = $citation_post_id;
        }

        $args = array(
            'posts_per_page' => $citations_per_page,
            'offset' => $offset,
            'post_type' => 'citation',
            'post_status' => array('publish', 'pending'),
            'post__not_in' => array($citation_post_id),
        );

        $args['meta_query'] = array('relation' => 'AND');

        if($post_id) {
            array_push($args['meta_query'], array(
                'key'     => 'citation_post_id',
                'value'   => $post_id,
            ));
        }

        $query = new WP_Query($args);
        wp_reset_postdata();
        wp_reset_query();

        $citations = array();
        if($query->have_posts()) {
            while ( $query->have_posts() ) {
                $query->the_post();
                $id = get_the_ID();
                $link = get_permalink($id);
                $title = get_the_title($id);
                $status = get_post_status($id);
                $excerpt = conikal_get_excerpt_by_id($id);
                $date = get_the_date('', $id);
                $time = sprintf(esc_html__('%s ago', 'campoal-tapo'), human_time_diff(get_the_time('U', $id), current_time('timestamp')));
                $opinion =  get_post_meta($id, 'citation_opinion', true);
                $petition_id =  get_post_meta($id, 'citation_post_id', true);
                $reference =  get_post_meta($id, 'citation_reference', true);
                $reference_image =  get_post_meta($id, 'citation_reference_image', true);
                $gallery = get_post_meta($id, 'citation_gallery', true);
                $images = conikal_get_gallery_images($gallery);
                $thumb_video = get_post_meta($id, 'citation_thumb_small', true);
                $comments = wp_count_comments($id);
                $comments_fomated = conikal_format_number('%!,0i', $comments->approved, true);

                if(has_post_thumbnail()) {
                    $thumb_id = get_post_thumbnail_id();
                    $thumbnail = wp_get_attachment_image_src($thumb_id, 'thumbnail', true);
                    $thumbnail = $thumbnail[0];
                } elseif ($thumb_video) {
                    $thumbnail = $thumb_video;
                } elseif ($gallery) {
                    $thumbnail = $images[1];
                } elseif ($reference_image) {
                    $thumbnail = $reference_image;
                } else {
                    $thumbnail = '';
                }

                $lazy_placeholder = conikal_lazy_load_placeholder('thumbnail-square');

                if ( (get_the_author_meta( 'ID' ) == $current_user->ID || current_user_can('editor') || current_user_can('administrator')) && is_user_logged_in()) {
                    $modify = true;
                } else {
                    $modify = false;
                }

                // check citation are voted or not
                $votes = get_post_meta($id, 'citation_vote', true);
                $vote_score = get_post_meta($id, 'citation_vote_score', true);
                if (is_array($votes) && array_key_exists($current_user->ID, $votes)) {
                    $vote_type = $votes[$current_user->ID];
                } else {
                    $vote_type = false;
                }

                // get author of citation
                $author_id      = get_the_author_meta( 'ID' );
                $author_name    = conikal_get_author_name($author_id);
                $author_link    = get_author_posts_url($author_id);
                $avatar         = conikal_get_avatar_url($author_id, array('size' => 128));
                $avatar_retina  = conikal_get_avatar_url($author_id, array('size' => 256));

                $citation = array(
                            'id'                => $id, 
                            'link'              => $link,
                            'title'             => $title,
                            'opinion'           => $opinion,
                            'opinion_color'     => ($opinion == 'yes' ? 'citation-label yes' : 'citation-label no'),
                            'opinion_text'      => ($opinion == 'yes' ? esc_html__('Agree', 'campoal-tapo') : esc_html__('Disagree', 'campoal-tapo')),
                            'status'            => $status,
                            'status_label'      => esc_html__('Pending', 'campoal-tapo'),
                            'excerpt'           => $excerpt,
                            'date'              => $date, 
                            'time'              => $time,
                            'petition_id'       => $petition_id,
                            'reference'         => $reference,
                            'site_domain'       => ($reference ? wp_parse_url($reference, 1) : ''),
                            'author_name'       => $author_name,
                            'author_link'       => $author_link,
                            'avatar'            => $avatar,
                            'avatar_retina'     => $avatar_retina,
                            'thumbnail'         => $thumbnail,
                            'lazy_placeholder'  => $lazy_placeholder,
                            'comments'          => $comments->approved,
                            'comments_fomated'  => $comments_fomated,
                            'comments_label'    => sprintf( _n('%s comment', '%s comments', $comments->approved, 'campoal-tapo'), $comments_fomated ),
                            'vote_score'        => (!empty($vote_score)) ? $vote_score : 0,
                            'vote_type'         => $vote_type,
                            'edit_link'         => ($link ? add_query_arg(array('section' => 'edit_citation', 'id' => $petition_id, 'citation_id' => $id), $link) : ''),
                            'modify'            => $modify,
                        );

                // load pending if have mofify permission
                if ($status == 'pending' && $modify) {
                    array_push($citations, $citation);
                } elseif ($status == 'publish') {
                    array_push($citations, $citation);
                }
            }
        }

        if ($query->have_posts()) {
            echo json_encode( array('status' => true, 'per_page' => $citations_per_page, 'found_posts' => count($citations), 'total' => $query->found_posts, 'citations' => $citations, 'message' => esc_html__('The citations was loaded successfully.', 'campoal-tapo')) );
            exit();
        } else {
            echo json_encode( array('status' => false, 'per_page' => $citations_per_page, 'total' => $query->found_posts, 'citations' => '', 'message' => esc_html__('Not found citations.', 'campoal-tapo')) );
            exit();
        }
        die();
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_load_citations_petition', 'conikal_load_citations_petition' );
add_action( 'wp_ajax_conikal_load_citations_petition', 'conikal_load_citations_petition' );


/**
 * Upvote and downvote citation
 *
 * @since Campoal Tapo 1.5.6
 */
if( !function_exists('conikal_vote_citation') ): 
    function conikal_vote_citation() {
        check_ajax_referer('citation_ajax_nonce', 'security');

        $post_id = isset($_POST['post_id']) ? sanitize_text_field($_POST['post_id']) : '';
        $user_id = isset($_POST['user_id']) ? sanitize_text_field($_POST['user_id']) : '';
        $citation_id = isset($_POST['citation_id']) ? sanitize_text_field($_POST['citation_id']) : '';
        $type = isset($_POST['type']) ? sanitize_text_field($_POST['type']) : '';
        $vote_number = isset($_POST['vote_number']) ? sanitize_text_field($_POST['vote_number']) : 0;

        $vote_key = 'citation_vote';
        $vote_key_score = 'citation_vote_score';
        $vote = get_post_meta($citation_id, $vote_key, true);
        $vote_score = get_post_meta($citation_id, $vote_key_score, true);

        if($vote == '') {
            $vote = array();
            delete_user_meta($citation_id, $vote_key);
            add_post_meta($citation_id, $vote_key, $vote);
        }

        if($vote_score == '') {
            delete_user_meta($citation_id, $vote_key_score);
            add_post_meta($citation_id, $vote_key_score, 0);
        }

        $vote[$user_id] = $type;
        update_post_meta($citation_id, $vote_key, $vote);
        update_post_meta($citation_id, $vote_key_score, intval($vote_number));

        $vote = get_post_meta($citation_id, $vote_key, true);
        $vote_score = get_post_meta($citation_id, $vote_key_score, true);

        echo json_encode(array('status' => true, 'type' => $type, 'votes' => $vote, 'score' => $vote_score));
        exit();
        die();
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_vote_citation', 'conikal_vote_citation' );
add_action( 'wp_ajax_conikal_vote_citation', 'conikal_vote_citation' );


/**
 * Enabled or disabled citation on single petition
 *
 * @since Campoal Tapo 1.5.6
 */
if( !function_exists('conikal_petition_save_setting') ): 
    function conikal_petition_save_setting() {
        check_ajax_referer('dashboard_petition_ajax_nonce', 'security');

        $post_id = isset($_POST['post_id']) ? sanitize_text_field($_POST['post_id']) : '';
        $setting_name = isset($_POST['setting_name']) ? sanitize_text_field($_POST['setting_name']) : '';
        $status = isset($_POST['status']) ? rest_sanitize_boolean($_POST['status']) : 0;

        $setting = update_post_meta($post_id, $setting_name, $status);
        $link = get_permalink($post_id);

        if (!empty($setting)) {
            echo json_encode(array('status'=>true, 'link' => $link, 'message' => 'The petition citation status was changed successfully!'));
            exit();
        }
       
        die();
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_petition_save_setting', 'conikal_petition_save_setting' );
add_action( 'wp_ajax_conikal_petition_save_setting', 'conikal_petition_save_setting' );


/**
 * Delete the citation
 *
 * @since Campoal Tapo 1.5.6
 */
if( !function_exists('conikal_delete_citation') ): 
    function conikal_delete_citation() {
        check_ajax_referer('citation_ajax_nonce', 'security');

        $del_id = isset($_POST['citation_id']) ? sanitize_text_field($_POST['citation_id']) : '';

        if ($del_id) {
            $del_citation = wp_delete_post($del_id);
        }

        if($del_citation) {
            echo json_encode(array('status'=>true, 'message'=>esc_html__('The citation was deleted successfully.', 'campoal-tapo')));
            exit();
        } else {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('Something went wrong. The citation was not deleted.', 'campoal-tapo')));
            exit();
        }

        die();
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_delete_citation', 'conikal_delete_citation' );
add_action( 'wp_ajax_conikal_delete_citation', 'conikal_delete_citation' );


/**
 * Enabled or disabled citation on single petition
 *
 * @since Campoal Tapo 1.5.6
 */
if( !function_exists('conikal_citation_fact_score') ): 
    function conikal_citation_fact_score($id) {
        $opinion_yes_number = get_post_meta($id, 'petition_opinion_yes', true);
        $opinion_yes_number = ($opinion_yes_number != '') ? $opinion_yes_number : 0;
        $opinion_no_number = get_post_meta($id, 'petition_opinion_no', true);
        $opinion_no_number = ($opinion_no_number != '') ? $opinion_no_number : 0;
        $opinion_total = (intval($opinion_yes_number) + intval($opinion_no_number));
        $fact_score = ($opinion_yes_number != 0 || $opinion_no_number != 0) ? (intval($opinion_yes_number) / intval($opinion_total)) * 100 : 0;
        $fact_score = round($fact_score);

        $results = array(
            'yes'   => $opinion_yes_number,
            'no'    => $opinion_no_number,
            'total' => $opinion_total,
            'score' => $fact_score,
        );

        return (object)$results;
    }
endif;

?>