<?php
/**
 * @package WordPress
 * @subpackage Campoal Tapo
 */


/**
 * Add support to give form
 *
 * @since 1.0
 *
 * @return array of donation level settings.
 */
if( !function_exists('conikal_give_petition_by_form_id') ) :
    function conikal_give_form_supports() {
        $give_form_supports = [
            'title',
            'thumbnail',
            'excerpt',
            'revisions',
            'comments',
            'author',
        ];

        return $give_form_supports;
    }
endif;
add_filter('give_forms_supports', 'conikal_give_form_supports');

 
/**
 * Change Donation level field on admin
 *
 * @param array $output An array of donation arguments.
 *
 * @since 1.0
 *
 * @return array of donation level settings.
 */
if ( !function_exists('conikal_add_description_level_field') ) :
    function conikal_add_description_level_field($output) {
        $price_placeholder = give_format_decimal( '1.00', false, false );
        $prefix = '_give_';
        $output = array(
            array(
                'name' => __( 'ID', 'campoal-tapo' ),
                'id'   => $prefix . 'id',
                'type' => 'levels_id',
            ),
            array(
                'name'       => __( 'Amount', 'campoal-tapo' ),
                'id'         => $prefix . 'amount',
                'type'       => 'text_small',
                'data_type'  => 'price',
                'attributes' => array(
                    'placeholder' => $price_placeholder,
                    'class'       => 'give-money-field',
                ),
            ),
            array(
                'name'       => __( 'Text', 'campoal-tapo' ),
                'id'         => $prefix . 'text',
                'type'       => 'text',
                'attributes' => array(
                    'placeholder' => __( 'Donation Level', 'campoal-tapo' ),
                    'class'       => 'give-multilevel-text-field',
                ),
            ),
            array(
                'name'       => __( 'Description', 'campoal-tapo' ),
                'id'         => $prefix . 'description',
                'type'       => 'wysiwyg',
                'args'       => array(
                    'media_buttons'         => true,
                    'textarea_rows'         => 3,
                    'drag_drop_upload'      => true,
                    'quicktags'             => false,
                    'dfw'                   => true,
                ),
            ),
            array(
                'name' => __( 'Default', 'campoal-tapo' ),
                'id'   => $prefix . 'default',
                'type' => 'give_default_radio_inline',
            ),
        );

        return $output;
    }
endif;
add_filter( 'give_donation_levels_table_row', 'conikal_add_description_level_field');


/**
 * Contribution level badge
 *
 * @param user id.
 *
 * @since 1.0
 *
 * @return html level badge.
 */
if ( !function_exists('conikal_contribution_level_badge') ) :
    function conikal_contribution_level_badge($user_id = null) {
        global $campoal_options;

        $level_badge = isset($campoal_options['conikal_contribute_level_badge_field']) ? $campoal_options['conikal_contribute_level_badge_field'] : 0;
        $give_form_id = isset($campoal_options['conikal_give_form_id_field']) ? $campoal_options['conikal_give_form_id_field'] : '';
        $minimum_donation_amount = isset($campoal_options['conikal_minimum_donation_amount_field']) ? intval($campoal_options['conikal_minimum_donation_amount_field']) : 0;

        $output = '';
        // check if user is decision maker
        $decisionmaker_id = get_user_meta($user_id, 'user_decision', true);
        if (!empty($decisionmaker_id)) {
            $indentify_verified = get_post_meta($decisionmaker_id, 'decisionmaker_indentify_verified', true);
            $output .= ($indentify_verified ? 'decision-maker-verified' : '');

            return $output;
        }

        $total_donation = 0;
        if ($level_badge == 1) {
            if ($give_form_id == '' || $give_form_id == 'all') {
                $total_donation = give_get_donation_stats_by_user($user_id);
                $total_donation = array_key_exists('total_spent', $total_donation) ? $total_donation['total_spent'] : 0;
                $total_donation = intval($total_donation);
                if ($total_donation >= $minimum_donation_amount) {
                    $output .= 'level-badge';
                }
            } else {
                // get donation by user with form id
                $give_form_id = array_map('intval', explode(',', $give_form_id));
                $donor_id = Give()->donors->get_column_by( 'id', 'user_id', $user_id );

                if (!empty($donor_id) && !empty($give_form_id)) {
                    $args = array(
                        'number'        => count($give_form_id),
                        'status'        => 'publish',
                        'donor'         => $donor_id,
                        'give_forms'    => $give_form_id,
                        'order'         => 'DESC'
                    );
                    $donations = give_get_payments( $args );
                    
                    // payment by donation id
                    if (!empty($donations)) {
                        foreach ($donations as $donation) {
                            $payment        = new Give_Payment($donation->ID);
                            $total_donation = intval($total_donation) + intval($payment->total);
                        }
            
                        if ($total_donation >= $minimum_donation_amount) {
                            $output .= 'level-badge';
                        }
                    }
                }
            }
        } else {
            $output = '';
        }

        return $output;
    }
endif;

/**
 * Donation Amount Field.
 *
 * Outputs the donation amount field that appears at the top of the donation forms. If the user has custom amount
 * enabled the field will output as a customizable input.
 *
 * @since  1.0
 *
 * @param  int   $form_id The form ID.
 * @param  array $args    An array of form arguments.
 *
 * @return void
 */
if ( !function_exists('conikal_give_output_donation_amount_top') ) :
    function conikal_give_output_donation_amount_top( $form_id = 0, $args = array(), $form = 0 ) {
        global $post;

        if (is_singular('update')) {
            $update_post_id = get_post_meta($post->ID, 'update_post_id', true);

            if (get_post_type($update_post_id) == 'petition') {
                // get fundraising mode setting
                $fundraising_mode   = conikal_fundraising_mode_setting($update_post_id);
                if ($fundraising_mode == 0) {
                    return;
                }
            } else if (get_post_type($update_post_id) != 'give_forms') {
                return;
            }
        } else if (is_singular('petition')) {
            // get fundraising mode setting
            $fundraising_mode   = conikal_fundraising_mode_setting($post->ID);
            if ($fundraising_mode == 0) {
                return;
            }
        } else if (!is_singular('give_forms')) {
            return;
        }

        $give_options        = give_get_settings();
        $variable_pricing    = give_has_variable_prices( $form_id );
        $allow_custom_amount = give_get_meta( $form_id, '_give_custom_amount', true );
        $currency_position   = isset( $give_options['currency_position'] ) ? $give_options['currency_position'] : 'before';
        $symbol              = give_currency_symbol( give_get_currency( $form_id, $args ) );
        $currency_output     = '<span class="give-currency-symbol give-currency-position-' . $currency_position . '">' . $symbol . '</span>';
        $default_amount      = give_format_amount(
            give_get_default_form_amount( $form_id ), array(
                'sanitize' => false,
                'currency' => give_get_currency( $form_id ),
            )
        );
        $custom_amount_text  = give_get_meta( $form_id, '_give_custom_amount_text', true );

        if ( empty( $custom_amount_text ) ) {
            $custom_amount_text = esc_html__( 'Give a Custom Amount', 'campoal-tapo' );
        }

        /**
         * Fires while displaying donation form, before donation level fields.
         *
         * @since 1.0
         *
         * @param int   $form_id The form ID.
         * @param array $args    An array of form arguments.
         */
        do_action( 'give_before_donation_levels', $form_id, $args );

        // Set Price, No Custom Amount Allowed means hidden price field.
        /*
        if ( ! give_is_setting_enabled( $allow_custom_amount ) ) {
            $display_label_field = give_get_meta( $form_id, '_give_reveal_label', true );
            $display_label       = ! empty( $args['continue_button_title'] ) ? $args['continue_button_title'] : ( ! empty( $display_label_field ) ? $display_label_field : esc_html__( 'Donate Now', 'campoal-tapo' ) );
            ?>
            <div class="ui padded segment give-total-wrap give-package-custom">
                <div class="ui medium dividing header"><?php echo esc_html($custom_amount_text) ?></div>
                <label class="give-hidden" for="give-amount-hidden"><?php esc_html_e( 'Donation Amount:', 'campoal-tapo' ); ?></label>
                <input id="give-amount" class="give-amount-hidden" type="hidden" name="give-amount"
                    value="<?php echo esc_attr($default_amount); ?>" required aria-required="true"/>
                <div class="set-price give-donation-amount form-row-wide">
                    <?php
                    if ( 'before' === $currency_position ) {
                        echo $currency_output;
                    }
                    ?>
                    <input id="give-amount-text" class="give-text-input give-amount-top" value="<?php echo esc_attr($default_amount); ?>" disabled>
                    <button class="ui large primary button give-btn-modal"><?php echo esc_html($display_label) ?></button>
                    <?php
                    if ( 'after' === $currency_position ) {
                        echo $currency_output;
                    }
                    ?>
                </div>
            </div>
            <?php
        } else { ?>
            <div class="ui padded secondary segment give-total-wrap give-package-custom">
                <div class="ui medium dividing header"><?php echo esc_html($custom_amount_text) ?></div>
                <div class="give-donation-amount form-row-wide">
                    <?php
                    if ( 'before' === $currency_position ) {
                        echo $currency_output;
                    }

                    $display_label_field = give_get_meta( $form_id, '_give_reveal_label', true );
                    $display_label       = ! empty( $args['continue_button_title'] ) ? $args['continue_button_title'] : ( ! empty( $display_label_field ) ? $display_label_field : esc_html__( 'Donate Now', 'campoal-tapo' ) );
                    ?>
                    <label class="give-hidden" for="give-amount"><?php esc_html_e( 'Donation Amount:', 'campoal-tapo' ); ?></label>
                    <input class="give-text-input give-amount-top" id="give-amount" name="give-amount" type="tel" placeholder="<?php esc_attr_e('Amount', 'campoal-tapo') ?>" value="<?php echo esc_attr($default_amount); ?>" autocomplete="off">
                    <?php
                    if ( 'after' === $currency_position ) {
                        echo $currency_output;
                    }
                    ?>
                    <button class="ui large primary button give-btn-modal"><?php echo esc_html($display_label) ?></button>
                </div>
            </div>
            <?php
        }
        */

        /**
         * Fires while displaying donation form, after donation amounf field(s).
         *
         * @since 1.0
         *
         * @param int   $form_id The form ID.
         * @param array $args    An array of form arguments.
         */
        do_action( 'give_after_donation_amount', $form_id, $args );

        // Output Variable Pricing Levels.
        if ( $variable_pricing ) {
            conikal_give_output_levels( $form_id );
        }

        /**
         * Fires while displaying donation form, after donation level fields.
         *
         * @since 1.0
         *
         * @param int   $form_id The form ID.
         * @param array $args    An array of form arguments.
         */
        //do_action( 'give_after_donation_levels', $form_id, $args );
    }
endif;
add_action( 'give_donation_form_bottom', 'conikal_give_output_donation_amount_top', 10, 2 );
// add_action( 'give_fields_donation_form_top', '__give_form_add_donation_hidden_field', 0, 3 );


/**
 * Outputs the Donation Levels in various formats such as dropdown, radios, and buttons.
 *
 * @since  1.0
 *
 * @param  int $form_id The form ID.
 *
 * @return string Donation levels.
 */
if ( !function_exists('conikal_give_output_levels') ) :
    function conikal_give_output_levels( $form_id ) {

        /**
         * Filter the variable pricing
         *
         * @since      1.0
         * @deprecated 2.2 Use give_get_donation_levels filter instead of give_form_variable_prices.
         *                 Check Give_Donate_Form::get_prices().
         *
         * @param array $prices Array of variable prices.
         * @param int   $form   Form ID.
         */
        $prices = apply_filters( 'give_form_variable_prices', give_get_variable_prices( $form_id ), $form_id );

        $display_style      = give_get_meta( $form_id, '_give_display_style', true );
        $custom_amount      = give_get_meta( $form_id, '_give_custom_amount', true );
        $custom_amount_text = give_get_meta( $form_id, '_give_custom_amount_text', true );

        if ( empty( $custom_amount_text ) ) {
            $custom_amount_text = esc_html__( 'Give a Custom Amount', 'campoal-tapo' );
        } ?>

        <div id="give-donation-level-button-wrap" class="give-donation-levels-wrap give-list-inline give-package-unit">

        <?php foreach ( $prices as $price ) {
            $level_text    = apply_filters( 'give_form_level_text', ! empty( $price['_give_text'] ) ? $price['_give_text'] : give_currency_filter( give_format_amount( $price['_give_amount'], array( 'sanitize' => false ) ), array( 'currency_code' => give_get_currency( $form_id ) ) ), $form_id, $price );
            $level_classes = apply_filters( 'give_form_level_classes', 'give-donation-level-btn give-btn give-btn-level-' . $price['_give_id']['level_id'] . ' ' . ( give_is_default_level_id( $price ) ? 'give-default-level ' : '' ) . 'ui fluid large button', $form_id, $price );
            $level_description    = ! empty( $price['_give_description'] ) ? $price['_give_description'] : '';

            $formatted_amount = give_format_amount(
                $price['_give_amount'], array(
                    'sanitize' => false,
                    'currency' => give_get_currency( $form_id ),
                )
            );

            $display_label_field = give_get_meta( $form_id, '_give_reveal_label', true );
            $display_label       = ! empty( $args['continue_button_title'] ) ? $args['continue_button_title'] : ( ! empty( $display_label_field ) ? $display_label_field : esc_html__( 'Donate Now', 'campoal-tapo' ) );
            ?>

            <div class="ui blurring padded secondary segment<?php echo esc_attr(!wp_is_mobile() ? ' give-level' : '') ?>">
                <h2 class="ui header">
                    <?php if (! empty($price['_give_text'])) { ?>
                        <span class="ui primary large label give-price-label"><?php echo give_currency_filter($formatted_amount, array( 'form_id' => $form_id )) ?></span>
                    <?php } ?>
                    <?php echo esc_html($level_text) ?>
                </h2>
                <div class="give-level-description"><?php echo wp_kses_post($level_description) ?></div>
                <?php if (!wp_is_mobile()) { ?>
                <div class="ui inverted dimmer">
                    <div class="content">
                        <button 
                            type="button" 
                            data-price-id="<?php echo esc_attr($price['_give_id']['level_id']) ?>" 
                            class="<?php echo esc_attr($level_classes) ?> give-btn-modal" 
                            value="<?php echo esc_attr($formatted_amount) ?>" 
                            data-default="<?php echo esc_attr(array_key_exists( '_give_default', $price ) ? 1 : 0) ?>">
                            <?php echo esc_html($display_label) ?>
                        </button>
                    </div>
                </div>
                <?php } else { ?>
                    <button 
                        type="button" 
                        data-price-id="<?php echo esc_attr($price['_give_id']['level_id']) ?>" 
                        class="<?php echo esc_attr($level_classes) ?> display none" 
                        value="<?php echo esc_attr($formatted_amount) ?>" 
                        data-default="<?php echo esc_attr(array_key_exists( '_give_default', $price ) ? 1 : 0) ?>">
                        <?php echo esc_html($display_label) ?>
                    </button>
                    <button 
                        type="button" 
                        data-level="<?php echo esc_attr($price['_give_id']['level_id']) ?>" 
                        class="ui fluid large button give-modal-strigger" 
                        id="give-modal-trigger-<?php echo esc_attr($price['_give_id']['level_id']) ?>">
                        <?php echo esc_html($display_label) ?>
                    </button>
                <?php } ?>
            </div>
        <?php } ?>
        </div>
        <?php
    }
endif;

?>