<?php 


/**
 * Register update custom post type
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_register_update_type') ):
    function conikal_register_update_type() {
        global $petition_config;

        $update_labels_args = array(
            'name'                  => esc_html__('Updates', 'campoal-tapo'),
            'singular_name'         => esc_html__('Update', 'campoal-tapo'),
            'add_new'               => esc_html__('Add New Update', 'campoal-tapo'),
            'add_new_item'          => esc_html__('Add Update', 'campoal-tapo'),
            'edit'                  => esc_html__('Edit', 'campoal-tapo'),
            'edit_item'             => esc_html__('Edit Update', 'campoal-tapo'),
            'new_item'              => esc_html__('New Update', 'campoal-tapo'),
            'view'                  => esc_html__('View', 'campoal-tapo'),
            'view_item'             => esc_html__('View Update', 'campoal-tapo'),
            'search_items'          => esc_html__('Search Updates', 'campoal-tapo'),
            'not_found'             => esc_html__('No Updates found', 'campoal-tapo'),
            'not_found_in_trash'    => esc_html__('No Updates found in Trash', 'campoal-tapo'),
            'parent'                => esc_html__('Parent Update', 'campoal-tapo'),
        );

        $permalinks = get_option('conikal_permalink_settings');
        if(!$permalinks) $permalinks = array();

        $permalinks['update_permalink_base'] = empty($permalinks['update_permalink_base']) ? 'update' : $permalinks['update_permalink_base'];

        $update_args = array(
            'labels'                => $update_labels_args,
            'public'                => true,
            'exclude_from_search '  => true,
            'has_archive'           => true,
            'rewrite'               => array('slug'=>_x($permalinks['update_permalink_base'],'URL slug','campoal-tapo'), 'with_front'=>true),
            'show_in_rest'          => true,
            'supports'              => array('title', 'author', 'editor', 'comments', 'shortlinks'),
            'can_export'            => true,
            'menu_icon'             => 'dashicons-megaphone'
        );

        $update_args = apply_filters('avf_update_cpt_args', $update_args);
        $petition_config['custom_post']['update']['args'] = $update_args;

        register_post_type('update', $update_args);
    }
endif;
add_action('init', 'conikal_register_update_type');

if( !function_exists('conikal_change_update_default_title') ):
    function conikal_change_update_default_title($title) {
        $screen = get_current_screen();
        if ('update' == $screen->post_type) {
            $title = esc_html__('Enter update title here', 'campoal-tapo');
        }
        return $title;
    }
endif;
add_filter('enter_title_here', 'conikal_change_update_default_title');


/**
 * Add custom column for update post type in admin
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_update_custom_column') ):
    function conikal_update_custom_column($defaults) {
        $defaults['post_views'] = esc_html__('Views','campoal-tapo');
        $defaults['petition'] = esc_html__('Petition','campoal-tapo');
        return $defaults;
    }
endif;
add_filter('manage_update_posts_columns', 'conikal_update_custom_column');

if( !function_exists('conikal_update_custom_column_views') ):
    function conikal_update_custom_column_views($column_name, $id) {
        if ($column_name === 'post_views') {
            $post_views = conikal_get_post_views(get_the_ID(), '');
            echo $post_views ? number_format_i18n($post_views) : '';
        }

        if ($column_name === 'petition') {
            $petition_id = get_post_meta(get_the_ID(), 'update_post_id', true);
            if ($petition_id) {
                echo '<a class="row-title" href="' . get_edit_post_link($petition_id) . '">' . get_the_title($petition_id) . '</a>';
            }
        }
    }
endif;
add_action('manage_update_posts_custom_column', 'conikal_update_custom_column_views', 5, 2);
?>