<?php
/**
 * @package WordPress
 * @subpackage Campoal Tapo
 */


/**
 * Add new update of petition
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_add_update_petition') ): 
    function conikal_add_update_petition() {
        check_ajax_referer('update_petition_ajax_nonce', 'security');
        global $campoal_options;

        $review_update          = isset($campoal_options['conikal_review_update_field']) ? $campoal_options['conikal_review_update_field'] : 0;
        $sendinblue_list_status = isset($campoal_options['conikal_sendinblue_list_field']) ? $campoal_options['conikal_sendinblue_list_field'] : 0;
        $sendinblue_key         = isset($campoal_options['conikal_sendinblue_key_field']) ? $campoal_options['conikal_sendinblue_key_field'] : '';

        $allowed_html = conikal_content_allowed_html();
        $user_id = isset($_POST['user_id']) ? sanitize_text_field($_POST['user_id']) : '';
        $post_id = isset($_POST['post_id']) ? sanitize_text_field($_POST['post_id']) : '';
        $update_id = isset($_POST['update_id']) ? sanitize_text_field($_POST['update_id']) : '';
        $petition_status = isset($_POST['petition_status']) ? sanitize_text_field($_POST['petition_status']) : 0;
        $title = isset($_POST['title']) ? sanitize_text_field($_POST['title']) : '';
        $content = isset($_POST['content']) ? wp_kses($_POST['content'], $allowed_html) : '';
        $type = isset($_POST['type']) ? sanitize_text_field($_POST['type']) : 'update';
        $media = isset($_POST['media']) ? sanitize_text_field($_POST['media']) : '';
        $graph_title = isset($_POST['graph_title']) ? sanitize_text_field($_POST['graph_title']) : '';
        $graph_description = isset($_POST['graph_description']) ? sanitize_text_field($_POST['graph_description']) : '';
        $graph_image = isset($_POST['graph_image']) ? sanitize_text_field($_POST['graph_image']) : '';
        $graph_site = isset($_POST['graph_site']) ? sanitize_text_field($_POST['graph_site']) : '';
        $petition_id = isset($_POST['petition_id']) ? sanitize_text_field($_POST['petition_id']) : '';
        $gallery = isset($_POST['gallery']) ? sanitize_text_field($_POST['gallery']) : '';
        $video = isset($_POST['video']) ? sanitize_text_field($_POST['video']) : '';
        $thumb = isset($_POST['thumb']) ? sanitize_text_field($_POST['thumb']) : '';
        $thumb_small = isset($_POST['thumb_small']) ? sanitize_text_field($_POST['thumb_small']) : '';
        $attach_id = isset($_POST['attach']) ? sanitize_text_field($_POST['attach']) : '';
        $notification = isset($_POST['notification']) ? sanitize_text_field($_POST['notification']) : '';
        $scheduled = isset($_POST['scheduled']) ? sanitize_text_field($_POST['scheduled']) : '';
        $campaign_id = isset($_POST['campaign_id']) ? sanitize_text_field($_POST['campaign_id']) : '';
        $campaign_status = isset($_POST['campaign_status']) ? sanitize_text_field($_POST['campaign_status']) : '';

        if($review_update == 0 || user_can($user_id, 'administrator') || user_can($user_id, 'editor')) {
            $update_status = 'publish';
        } else {
            $update_status = 'pending';
        }

        $update_arg = array(
            'post_title' => $title,
            'post_content' => $content,
            'post_type' => 'update',
            'post_status' => $update_status,
            'post_author' => $user_id
        );

        if ($media != '') {
            $type = 'featured';
        }

        if($update_id != '') {
            $update_arg['ID'] = $update_id;
        } else {
            $update_arg['post_status'] = $update_status;
        }

        if($title == '') {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('Title field is mandatory.', 'campoal-tapo')));
            exit();
        }
        if($content == '' || strlen($content) < 10) {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('Content field is mandatory and minimum 10 characters.', 'campoal-tapo')));
            exit();
        }
        if($petition_id == '') {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('Petition id field is mandatory.', 'campoal-tapo')));
            exit();
        }
        
        if ($update_id != '') {
            $update = wp_update_post($update_arg);
        } else {
            $update = wp_insert_post($update_arg);
        }

        update_post_meta($petition_id, 'petition_status', $petition_status);

        update_post_meta($update, 'update_post_id', $petition_id);
        update_post_meta($update, 'update_type', $type);
        update_post_meta($update, 'update_media', $media);
        update_post_meta($update, 'update_graph_title', $graph_title);
        update_post_meta($update, 'update_graph_description', $graph_description);
        update_post_meta($update, 'update_graph_image', $graph_image);
        update_post_meta($update, 'update_graph_site', $graph_site);
        update_post_meta($update, 'update_gallery', $gallery);
        update_post_meta($update, 'update_video', $video);
        update_post_meta($update, 'update_thumb', $thumb);
        update_post_meta($update, 'update_thumb_small', $thumb_small);
        update_post_meta($update, 'update_notification', $notification);
        update_post_meta($update, 'update_scheduled', $scheduled);
        set_post_thumbnail( $update, $attach_id );

        // send email notification for supporters
        $sendinblue_campaign = false;
        if ($sendinblue_list_status == 1 && $sendinblue_key != '' && $update_status == 'publish') {
            if (!empty($notification) && $notification != 'not') {
                if ($campaign_id != '') {
                    $action = 'update';
                } else {
                    $action = 'create';
                }
                $sendinblue_campaign = conikal_sendinblue_campaigns($update, $user_id, $content, $notification, $scheduled, $action);
            } else if ($notification == 'not' && $campaign_id != '' && $campaign_status == 1) {
                $sendinblue_campaign = conikal_sendinblue_campaign_status($campaign_id, 'suspended');
            }
        } elseif (!empty($notification) && $notification != 'not') {
            conikal_new_update_notification($petition_id, $update, $user_id, $update_id);
        }

        // send email notification for admin
        conikal_new_update_notification($petition_id, $update, $user_id, $update_id, 0);

        // send email when update to decision maker
        conikal_decision_maker_notification('update', $petition_id, $user_id, $update);

        // send email declare victory to decision maker
        if ($petition_status == 1) {
            conikal_decision_maker_notification('victory', $petition_id, $user_id, $update);
        }

        // get link after submited update
        $approve = get_post_status($update);
        if ($approve == 'pending') {
            $petition_link = get_permalink($petition_id);
            if ($petition_link) {
                $update_link = add_query_arg(array('action' => 'update_pending'), $petition_link);
            }
        } else {
            $update_link = get_permalink($update);
            if ($update_id != '') {
                $update_link = add_query_arg(array('action' => 'update_edited'), $update_link);
            } 
        }

        if($update != 0) {
            echo json_encode(array('status' => true, 'ID' => $update, 'link' => $update_link, 'campaign' => $sendinblue_campaign, 'message'=>esc_html__('The update was successfully saved.', 'campoal-tapo')));
            exit();
        } else {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('Something went wrong. The update was not saved.', 'campoal-tapo')));
            exit();
        }

        die();
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_add_update_petition', 'conikal_add_update_petition' );
add_action( 'wp_ajax_conikal_add_update_petition', 'conikal_add_update_petition' );


/**
 * Get the update of petition
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_update_petition') ): 
    function conikal_update_petition($post_id, $show = 0, $orderby = 'date', $order = 'DESC') {
        global $campoal_options;
        global $paged;

        if ($show != 0) {
            $updates_per_page = $show;
        } else {
            $updates_per_page = isset($campoal_options['conikal_updates_per_page_field']) ? $campoal_options['conikal_updates_per_page_field'] : 5;
        }

        $paged = (get_query_var('paged')) ? get_query_var('paged') : 1;
        $args = array(
            'posts_per_page'    => $updates_per_page,
            'paged'             => $paged,
            'post_type'         => 'update',
            'post_status'       => 'publish',
            'orderby'           => $orderby,
            'order'             => $order,
        );

        $args['meta_query'] = array('relation' => 'AND');

        if($post_id != '') {
            array_push($args['meta_query'], array(
                'key'     => 'update_post_id',
                'value'   => $post_id,
            ));
        }

        $query = new WP_Query($args);

        wp_reset_postdata();
        wp_reset_query(); 
        
        return $query;
    }
endif;


/**
 * Load more updates of petition
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_load_updates_petition') ): 
    function conikal_load_updates_petition() {
        check_ajax_referer('update_petition_ajax_nonce', 'security');
        global $campoal_options;
        global $current_user;

        $updates_per_page = isset($campoal_options['conikal_updates_per_page_field']) ? $campoal_options['conikal_updates_per_page_field'] : 5;
        $page_dashboard_petition = isset($campoal_options['conikal_page_dashboard_petition_field']) ? $campoal_options['conikal_page_dashboard_petition_field'] : 0;
        $page_dashboard_petition = $page_dashboard_petition ? get_permalink($page_dashboard_petition) : '';
        $sort = isset($_GET['sort']) ? sanitize_text_field($_GET['sort']) : 'newest';
        $update_post_id = isset($_POST['post_id']) ? sanitize_text_field($_POST['post_id']) : '';
        $user_id = isset($_POST['user_id']) ? sanitize_text_field($_POST['user_id']) : '';
        $offset = isset($_POST['offset']) ? sanitize_text_field($_POST['offset']) : 5;

        $post_type = get_post_type($update_post_id);
        if ($post_type == 'update') {
            $post_id = get_post_meta($update_post_id, 'update_post_id', true); 
        } else {
            $post_id = $update_post_id;
        }

        $args = array(
            'posts_per_page' => $updates_per_page,
            'offset' => $offset,
            'post_type' => 'update',
            'post_status' => array('publish', 'pending'),
            'post__not_in' => array($update_post_id),
        );

        $args['meta_query'] = array('relation' => 'AND');

        if($post_id) {
            array_push($args['meta_query'], array(
                'key'     => 'update_post_id',
                'value'   => $post_id,
            ));
        }

        $query = new WP_Query($args);
        wp_reset_postdata();
        wp_reset_query();

        $updates = array();
        if($query->have_posts()) {
            while ( $query->have_posts() ) {
                $query->the_post();
                $id = get_the_ID();
                $link = get_permalink($id);
                $title = get_the_title($id);
                $status = get_post_status($id);
                $excerpt = conikal_get_excerpt_by_id($id);
                $date = get_the_date('', $id);
                $time = sprintf(esc_html__('%s ago', 'campoal-tapo'), human_time_diff(get_the_time('U', $id), current_time('timestamp')));
                $type =  get_post_meta($id, 'update_type', true);
                $petition_id =  get_post_meta($id, 'update_post_id', true);
                $media =  get_post_meta($id, 'update_media', true);
                $gallery = get_post_meta($id, 'update_gallery', true);
                $images = conikal_get_gallery_images($gallery);
                $thumb_video = get_post_meta($id, 'update_thumb_small', true);
                $comments = wp_count_comments($id);
                $comments_fomated = conikal_format_number('%!,0i', $comments->approved, true);

                if(has_post_thumbnail()) {
                    $thumb_id = get_post_thumbnail_id();
                    $thumbnail = wp_get_attachment_image_src($thumb_id, 'thumbnail', true);
                    $thumbnail = $thumbnail[0];
                } elseif ($thumb_video) {
                    $thumbnail = $thumb_video;
                } elseif ($gallery) {
                    $thumbnail = $images[1];
                } else {
                    $thumbnail = '';
                }

                $lazy_placeholder = conikal_lazy_load_placeholder('thumbnail-square');

                if ( (get_the_author_meta( 'ID' ) == $current_user->ID || current_user_can('editor') || current_user_can('administrator') || conikal_co_author_permission($petition_id)) && is_user_logged_in()) {
                    $modify = true;
                } else {
                    $modify = false;
                }

                // get type title and icon update
                $update_type_title = conikal_get_update_type($type);

                $update = array(
                            'id'                => $id, 
                            'link'              => $link,
                            'title'             => $title,
                            'type'              => $type,
                            'status'            => $status,
                            'status_label'      => esc_html__('Pending', 'campoal-tapo'),
                            'feed'              => $update_type_title['text'],
                            'icon'              => $update_type_title['icon'],
                            'icon_victory'      => conikal_custom_icon('victory_inverse'),
                            'excerpt'           => $excerpt,
                            'date'              => $date, 
                            'time'              => $time,
                            'petition_id'       => $petition_id,
                            'media'             => $media,
                            'thumbnail'         => $thumbnail,
                            'lazy_placeholder'  => $lazy_placeholder,
                            'comments'          => $comments->approved,
                            'comments_fomated'  => $comments_fomated,
                            'comments_label'    => sprintf( _n('%s comment', '%s comments', $comments->approved, 'campoal-tapo'), $comments_fomated ),
                            'edit_link'         => ($page_dashboard_petition ? add_query_arg(array('section' => 'add_update', 'id' => $petition_id, 'update_id' => $id), $page_dashboard_petition) : ''),
                            'modify'            => $modify
                        );

                // load pending if have mofify permission
                if ($status == 'pending' && $modify) {
                    array_push($updates, $update);
                } elseif ($status == 'publish') {
                    array_push($updates, $update);
                }
            }
        }

        if ($query->have_posts()) {
            echo json_encode( array('status' => true, 'per_page' => $updates_per_page, 'found_posts' => count($updates), 'total' => $query->found_posts, 'updates' => $updates, 'message' => esc_html__('The updates was loaded successfully.', 'campoal-tapo')) );
            exit();
        } else {
            echo json_encode( array('status' => false, 'per_page' => $updates_per_page, 'total' => $query->found_posts, 'updates' => '', 'message' => esc_html__('Not found updates.', 'campoal-tapo')) );
            exit();
        }
        die();
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_load_updates_petition', 'conikal_load_updates_petition' );
add_action( 'wp_ajax_conikal_load_updates_petition', 'conikal_load_updates_petition' );


/**
 * Delete the update of petiiton
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_delete_update') ): 
    function conikal_delete_update() {
        check_ajax_referer('update_petition_ajax_nonce', 'security');
        global $campoal_options;

        $sendinblue_list_status = isset($campoal_options['conikal_sendinblue_list_field']) ? $campoal_options['conikal_sendinblue_list_field'] : 0;
        $sendinblue_key         = isset($campoal_options['conikal_sendinblue_key_field']) ? $campoal_options['conikal_sendinblue_key_field'] : '';

        $del_id = isset($_POST['update_id']) ? sanitize_text_field($_POST['update_id']) : '';
        $campaign_id = get_post_meta($del_id, 'update_campaign_id', true);

        // deleta sendinblue campaign
        if ($sendinblue_list_status == 1 && $sendinblue_key != '' && $campaign_id != '') {
            $delete_campaign = conikal_sendinblue_campaign_delete($campaign_id);
        } else {
            $delete_campaign = false;
        }

        $del_update = wp_delete_post($del_id);

        if($del_update) {
            echo json_encode(array('status'=>true, 'campaign' => $delete_campaign, 'message'=>esc_html__('The update was successfully deleted.', 'campoal-tapo')));
            exit();
        } else {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('Something went wrong. The update was not deleted.', 'campoal-tapo')));
            exit();
        }

        die();
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_delete_update', 'conikal_delete_update' );
add_action( 'wp_ajax_conikal_delete_update', 'conikal_delete_update' );


/**
* Get petition update type icon and title
*
* @since Campoal Tapo 1.0.0
*/
if (!function_exists('conikal_get_update_type')) :
    function conikal_get_update_type($type) {
        $update_type = array();
        switch ($type) {
            case 'update':
                $update_type['text'] = esc_html__('Campaign Update', 'campoal-tapo');
                $update_type['icon'] = 'announcement icon';
                break;
            case 'featured':
                $update_type['text'] = esc_html__('Featured on Press', 'campoal-tapo');
                $update_type['icon'] = 'star icon';
                break;
            case 'responsive':
                $update_type['text'] = esc_html__('Decision Maker Response', 'campoal-tapo');
                $update_type['icon'] = 'reply icon';
                break;
            case 'victory':
                $update_type['text'] = esc_html__('Petition Victory', 'campoal-tapo');
                $update_type['icon'] = 'flag icon';
                break;
            default:
                $update_type['text'] = esc_html__('Petition Update', 'campoal-tapo');
                $update_type['icon'] = 'repeat icon';
                break;
        }

        return $update_type;    
    }
endif;


/**
* Send email for supporters when Update is publish
*
* @since Campoal Tapo 1.3.1
*/
if (!function_exists('conikal_update_published_notification')) :
    function conikal_update_published_notification($ID, $post) {
        global $campoal_options;

        $update_id              = $post->ID;
        $campaign_id            = get_post_meta($update_id, 'update_campaign_id', true);
        $sendinblue_list_status = isset($campoal_options['conikal_sendinblue_list_field']) ? $campoal_options['conikal_sendinblue_list_field'] : 0;
        $sendinblue_key         = isset($campoal_options['conikal_sendinblue_key_field']) ? $campoal_options['conikal_sendinblue_key_field'] : '';

        $update_status          = get_post_status($update_id);
        $update_title           = get_the_title($update_id);
        $notification           = 'now';
        $scheduled              = get_post_meta($update_id, 'update_scheduled', true);
        $petition_id            = get_post_meta($update_id, 'update_post_id', true);
        $author_id              = get_post_field('post_author', $update_id);
        $content                = get_the_content('', false, $update_id);

        // send email notification for supporters
        $sendinblue_campaign = false;
        if ($sendinblue_list_status == 1 && $sendinblue_key != '') {
            if ($notification != 'not') {
                if ($campaign_id && $campaign_id != '') {
                    $action = 'update';
                } else {
                    $action = 'create';
                }
                $sendinblue_campaign = conikal_sendinblue_campaigns($update_id, $author_id, $content, $notification, $scheduled, $action);
            }
        } elseif ($notification != 'not') {
            conikal_new_update_notification($petition_id, $update_id, $author_id, $update_id);
        }

        return $sendinblue_campaign;
    }
endif;
add_action( 'publish_update', 'conikal_update_published_notification', 10, 2 );

?>