<?php
/**
 * @package WordPress
 * @subpackage Campoal Tapo
 */


/**
 * Recent posts widget
 *
 * @since Campoal Tapo 1.0.0
 */
class Recent_Posts_Widget extends WP_Widget {
    function __construct() {
        $widget_ops = array('classname' => 'recent_posts_sidebar', 'description' => 'Petition posts recently.');
        $control_ops = array('id_base' => 'recent_posts_sidebar');
        parent::__construct('recent_posts_sidebar', 'Campoal Posts Recently', $widget_ops, $control_ops);
    }

    function form($instance) {
        $defaults = array(
            'title' => '',
            'limit' => 5,
            'link_only' => 1
        );
        $instance = wp_parse_args((array) $instance, $defaults); ?>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('title')) ?>"><?php esc_html_e('Title', 'campoal-tapo') ?>:</label>
            <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('title')) ?>" name="<?php echo esc_attr($this->get_field_name('title')) ?>" value="<?php echo esc_attr($instance['title']) ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('limit')) ?>"><?php esc_html_e('Number of posts to show', 'campoal-tapo') ?>:</label>
            <input type="text" size="3" id="<?php echo esc_attr($this->get_field_id('limit')) ?>" name="<?php echo esc_attr($this->get_field_name('limit')) ?>" value="<?php echo esc_attr($instance['limit']) ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('link_only')) ?>"><?php esc_html_e('Only text link', 'campoal-tapo') ?>:</label>
            <input type="checkbox" id="<?php echo esc_attr($this->get_field_id('link_only')) ?>" name="<?php echo esc_attr($this->get_field_name('link_only')) ?>" value="1"<?php echo esc_attr($instance['link_only'] ? ' checked' : '') ?> />
        </p>
    <?php }

    function update($new_instance, $old_instance) {
        $instance = $old_instance;
        $instance['title'] = sanitize_text_field($new_instance['title']);
        $instance['limit'] = sanitize_text_field($new_instance['limit']);
        $instance['link_only'] = array_key_exists('link_only', $new_instance) ? sanitize_text_field($new_instance['link_only']) : '';

        if(function_exists('icl_register_string')) {
            icl_register_string('conikal_recent_posts_widget', 'recent_posts_widget_title', sanitize_text_field($new_instance['title']));
            icl_register_string('conikal_recent_posts_widget', 'recent_posts_widget_limit', sanitize_text_field($new_instance['limit']));
            icl_register_string('conikal_recent_posts_widget', 'recent_posts_widget_limit', sanitize_text_field($new_instance['link_only']));
        }

        return $instance;
    }

    function widget($args, $instance) {
        extract($args);
        $display = '';
        $title = apply_filters('widget_title', $instance['title']);

        echo wp_kses_post($before_widget);
        if ($title) {
            echo wp_kses_post($before_title) . esc_html($title) . wp_kses_post($after_title);
        }

        if ($instance['limit'] && $instance['limit'] != '') {
            $limit = $instance['limit'];
        } else {
            $limit = 5;
        }

        if ($instance['link_only'] && $instance['link_only'] != '') {
            $link_only = $instance['link_only'];
        } else {
            $link_only = false;
        }

        $args = array(
            'posts_per_page'   => $instance['limit'],
            'orderby'          => 'post_date',
            'order'            => 'DESC',
            'post_status'      => 'publish'
        );
        
        $postslist = new WP_Query($args);

        wp_reset_postdata();
        wp_reset_query();

        if ( $postslist->have_posts() ) : ?>
            <div class="ui relaxed items">
            <?php while( $postslist->have_posts() ) : $postslist->the_post();
                
                /*
                 * Include the post template for the content.
                 * If you want to override this in a child theme, then include a file
                 */
                get_template_part('loop/content-post', ($link_only ? 'link' : 'widget'));
                ?>
            <?php endwhile; ?>
            </div>
        <?php endif; ?>

        <?php
        echo wp_kses_post($after_widget);
    }
} ?>