<?php

/**
 * Recent petitions shortcode
 */
if( !function_exists('conikal_fundraising_campaign_shortcode') ): 
    function conikal_fundraising_campaign_shortcode($attrs, $content = null) {
        extract(shortcode_atts(array(
            'title'             => 'Fundraising campaigns',
            'show'              => '4',
            'category'          => '',
            'form_ids'          => '',
            'style'             => 'grid',
            'carousel'          => 'no',
            'column'            => 'four',
            'hover'             => false,
            'order'             => 'DESC',
            'orderby'           => 'date',
        ), $attrs));

        if (class_exists('Give')) {
            global $campoal_options;
            $fundraising_with_petition  = isset($campoal_options['conikal_fundraising_only_field']) ? $campoal_options['conikal_fundraising_only_field'] : 1;

            $give_prefix = '_give_';

            if ($form_ids != '') {
                $form_ids = array_map('intval', explode(',', $form_ids));
            }

            $paged = (get_query_var('paged')) ? get_query_var('paged') : 1;

            $args = array(
                'posts_per_page'   => $show,
                'paged'            => $paged,
                'post_type'        => 'give_forms',
                'post_status'      => 'publish',
                'post__in'         => $form_ids,
                'order'            => $order,
                'orderby'          => conikal_meta_key_ordering_filter($orderby),
            );

            // add meta key or supporters ordering
            if ($orderby == 'views') {
                $args['meta_key'] = 'post_views_count';
            }

            if ($category != '') {
                $category = explode(',', $category);
                $categories = array();
                foreach ($category as $id_slug) {
                    $id_slug = str_replace(' ', '', $id_slug);
                    $term = get_term_by('slug', $id_slug, 'give_forms_category');
                    if (!$term) {
                        $term = get_term_by('id', $id_slug, 'give_forms_category');
                    }
                    array_push($categories, $term->term_id);
                }

                $args['tax_query'] = array(
                    'relation' => 'OR',
                    array(
                        'taxonomy' => 'give_forms_category',
                        'terms'    => $categories,
                    )
                );
            }

            $args['meta_query'] = array('relation' => 'AND');

            if ($fundraising_with_petition == 1) {
                array_push($args['meta_query'], array(
                   'key'     => $give_prefix . 'petition_id',
                   'compare' => 'NOT EXISTS'
               ));
            }

            $forms = new WP_Query($args);

            $return_string = conikal_shortcode_loop_give_form($forms, $attrs, $content);

            wp_reset_postdata();
            wp_reset_query();
        } else {
            $return_string = '<div class="ui info message">
              <i class="close icon"></i>
              <div class="header">' . esc_html__('Fundraising shortcode can not working without Give plugin!', 'campoal-tapo') . '</div>
                ' . esc_html__('Please install and active Give plugin to make this shortcode working.', 'campoal-tapo') . '
            </div>';
        }

        return $return_string;
    }
endif;


// interact with visual composer

add_action( 'vc_before_init', 'conikal_vc_fundraising_campaign_shortcode' );
function conikal_vc_fundraising_campaign_shortcode() {
   vc_map( array(
      "name" => esc_html__('Fundraising', 'campoal-tapo'),
      "base" => 'fundraising',
      "class" => '',
      "category" => esc_html__('Campoal', 'campoal-tapo'),
      'admin_enqueue_js' => plugin_dir_url( __FILE__ ) . 'vc_extend/bartag.js',
      'admin_enqueue_css' => plugin_dir_url( __FILE__ ) . 'vc_extend/bartag.css',
      "icon" => plugin_dir_url( __FILE__ ) . 'images/campoal-icon.svg',
      "params" => array(
        array(
            "type" => 'textfield',
            "holder" => 'div',
            "class" => '',
            "heading" => esc_html__('Title', 'campoal-tapo'),
            "param_name" => 'title',
            "value" => 'Recent Petitions',
            "description" => esc_html__('Title of Segment', 'campoal-tapo')
        ),
        array(
            "type" => 'textfield',
            "holder" => 'div',
            "class" => '',
            "heading" => esc_html__('Show Number', 'campoal-tapo'),
            "param_name" => 'show',
            "value" => 4,
            "description" => esc_html__('Number of Petitions', 'campoal-tapo')
        ),
        array(
            "type" => 'textfield',
            "holder" => 'div',
            "class" => '',
            "heading" => esc_html__('Category IDs or Slugs (separated by comma)', 'campoal-tapo'),
            "param_name" => 'category',
            "value" => '',
            "description" => esc_html__('Category ID or Slugs comma-separated list of IDs (this or any children)', 'campoal-tapo')
        ),
        array(
            "type" => 'textfield',
            "holder" => 'div',
            "class" => '',
            "heading" => esc_html__('Form IDs (separated by comma)', 'campoal-tapo'),
            "param_name" => 'form_ids',
            "value" => '',
            "description" => esc_html__('Form IDs comma-separated list of IDs', 'campoal-tapo')
        ),
        array(
            "type" => 'dropdown',
            "holder" => 'div',
            "class" => '',
            "heading" => esc_html__('Style', 'campoal-tapo'),
            "param_name" => 'style',
            "value" => array(
                'Grid' => 'grid',
                'List' => 'list'
                ),
            "std" => 'grid',
            "description" => esc_html__('Style Display of Petition', 'campoal-tapo')
        ),
        array(
            "type" => 'dropdown',
            "holder" => 'div',
            "class" => '',
            "heading" => esc_html__('Carousel Mode', 'campoal-tapo'),
            "param_name" => 'carousel',
            "value" => array(
                'No' => 'no',
                'Yes' => 'yes',
                ),
            "std" => 'no',
            "description" => esc_html__('Display Petitions follow Carousel style', 'campoal-tapo')
        ),
        array(
            "type" => 'dropdown',
            "holder" => 'div',
            "class" => '',
            "heading" => esc_html__('Column', 'campoal-tapo'),
            "param_name" => 'column',
            "value" => conikal_shortcode_column_options(),
            "std" => 'four',
            "description" => esc_html__('Column of Petitions', 'campoal-tapo')
        ),
        array(
            "type" => 'checkbox',
            "holder" => 'div',
            "class" => '',
            "heading" => esc_html__('Active hover', 'campoal-tapo'),
            "param_name" => 'hover',
            "description" => esc_html__('Active hover card', 'campoal-tapo')
        ),
        array(
            "type" => 'dropdown',
            "holder" => 'div',
            "class" => '',
            "heading" => esc_html__('Order', 'campoal-tapo'),
            "param_name" => 'order',
            "value" => array_flip(conikal_sort_petition_options('order')),
            "std" => 'DESC',
            "description" => esc_html__('Ordering petitions', 'campoal-tapo')
        ),
        array(
            "type" => 'dropdown',
            "holder" => 'div',
            "class" => '',
            "heading" => esc_html__('Sort by', 'campoal-tapo'),
            "param_name" => 'orderby',
            "value" => array_flip(conikal_sort_petition_options('orderby')),
            "std" => 'date',
            "description" => esc_html__('Sort petittion by conditional', 'campoal-tapo')
        ),
      )
   ) );
}

?>