<?php

/**
 * Petition list content in shortcode
 */
if (!function_exists('conikal_shortcode_give_form_card')) :
    function conikal_shortcode_give_form_card($form, $attrs, $content = null) {
        // convert shortcode attributes to variables
        extract(shortcode_atts(array(
            'title'     => 'Fundraising campaigns',
            'show'      => '4',
            'category'  => '',
            'forms_ids' => '',
            'style'     => 'grid',
            'carousel'  => 'no',
            'column'    => 'four',
            'hover'     => false,
            'order'     => 'DESC',
            'orderby'   => 'date',
        ), $attrs));

        global $campoal_options;

        $external_link      = isset($campoal_options['conikal_external_link_field']) ? $campoal_options['conikal_external_link_field'] : 0;
        $view_counter       = isset($campoal_options['conikal_view_counter_field']) ? $campoal_options['conikal_view_counter_field'] : 0;
        $excerpt_words_grid = isset($campoal_options['conikal_excerpt_words_grid_field']) ? $campoal_options['conikal_excerpt_words_grid_field'] : 1;
        
        $give_prefix        = '_give_';

        $form_id            = get_the_ID();
        $petition_id        = get_post_meta($form_id, $give_prefix . 'petition_id', true);
        $link               = get_permalink($form_id);
        $title              = get_the_title($form_id);
        $comments           = wp_count_comments($form_id);
        $category           = wp_get_post_terms($form_id, 'give_forms_category', true);
        $backers            = give_get_form_sales_stats( $form_id );
        $content            = get_post_meta($form_id, $give_prefix . 'form_content', true);
        $excerpt            = conikal_get_excerpt_by_id($form_id, $excerpt_words_grid, $content);
        $city               = get_post_meta($form_id, $give_prefix . 'city', true);
        $state              = get_post_meta($form_id, $give_prefix . 'state', true);
        $country            = get_post_meta($form_id, $give_prefix . 'country', true);

        $author_name        = conikal_get_author_name( get_the_author_meta('ID') );
        $author_url         = get_author_posts_url( get_the_author_meta( 'ID' ), get_the_author_meta( 'user_nicename' ));
        $avatar             = conikal_get_avatar_url( get_the_author_meta('ID'), array('size' => 64) );
        $avatar_retina      = conikal_get_avatar_url( get_the_author_meta('ID'), array('size' => 128) );

        $user_city          = get_user_meta( get_the_author_meta('ID'), 'user_city', true);
        $user_state         = get_user_meta( get_the_author_meta('ID'), 'user_state', true);
        $user_country       = get_user_meta( get_the_author_meta('ID'), 'user_country', true); 

        // lazy placeholder
        $thumbnail          = conikal_get_petition_thumbnail($form_id, 'conikal-petition-thumbnail', false);
        $thumbnail_retina   = conikal_get_petition_thumbnail($form_id, 'conikal-petition-thumbnail-retina', false);
        
        $lazy_placeholder   = conikal_lazy_load_placeholder('thumbnail-small');
        $lazy_placeholder_avatar = conikal_lazy_load_placeholder('avatar');

        $post_views         = conikal_format_number('%!,0i', (int) conikal_get_post_views($form_id), true);

        $goal_option        = get_post_meta($form_id, $give_prefix . 'goal_option', true);

        // use petition thumbnail if donation form doesn't exist thumbnail
        if (!$thumbnail && !empty($petition_id)) {
            $thumbnail          = conikal_get_petition_thumbnail($petition_id, 'conikal-petition-thumbnail', false);
            $thumbnail_retina   = conikal_get_petition_thumbnail($petition_id, 'conikal-petition-thumbnail-retina', false);

            if(!is_array($category) || !isset($category[0])) {
                $category       = wp_get_post_terms($petition_id, 'petition_category', true);
            }

            $city               = get_post_meta($petition_id, 'petition_city', true);
            $state              = get_post_meta($petition_id, 'petition_state', true);
            $country            = get_post_meta($petition_id, 'petition_country', true);
        }

        $return_string = '';
        if ( conikal_carousel_mode($carousel) == 0 ) {
            $return_string .= '<div class="card petition-card' . esc_attr($hover == true ? ' active-hover' : '') . '">';
        } else {
            $return_string .= '<div>';
            $return_string .= '<div class="ui fluid card petition-card' . esc_attr($hover == true ? ' active-hover' : '') . '" style="margin-bottom: 2px;">';
        }
            if (give_is_setting_enabled( $goal_option )) {
                $goal_stats         = give_goal_progress_stats( $form_id );
                if ($goal_stats['raw_goal'] != 0 && $goal_stats['raw_actual'] >= $goal_stats['raw_goal']) {
                    $return_string .= '<span class="ui primary right large corner label victory-label">' . conikal_custom_icon('victory') . '</span>';
                }
            }
            if (!empty($thumbnail)) :
                $return_string .= '<a href="' . esc_url($link) . '" class="image" target="' . esc_attr($external_link != 0 ? '_blank' : '_self') .'" ' . esc_attr($external_link != 0 ? '' : 'data-bjax') . '>';
                    $return_string .= '<div class="ui dimmer">
                        <div class="content">
                            <div class="center">
                                <div class="ui icon inverted circular big button"><i class="external alternate icon"></i></div>
                            </div>';
                            if ($country || $state || $city) {
                                $return_string .= '<div class="petition-location"><i class="map marker icon"></i>' . esc_html($city ? $city . ', ' : '') . esc_html($state ? $state . ', ' : '') . esc_html($country ? $country : '') . '</div>';
                            }
                            if ($view_counter == 1 && function_exists('conikal_get_post_views')) {
                            $return_string .= '<div class="view-counter">
                                <i class="eye icon"></i> ' . esc_html($post_views) . '
                            </div>';
                            }
                        $return_string .= '</div>
                    </div>
                    <img class="ui fluid image lazy" data-src="' . esc_url($thumbnail) . '" data-retina="' . esc_url($thumbnail_retina) . '" src="' . esc_url($lazy_placeholder) . '" alt="' . esc_attr($title) . '">
                </a>';
            endif;
            $return_string .= '<div class="content petition-content">
                <div class="meta">';
                    if (is_array($category) && isset($category[0])) :
                        $return_string .= '<a href="' . get_term_link($category[0]->term_id) . '" data-bjax>' . esc_html($category[0]->name) . '</a>';
                    endif;
                $return_string .= '</div>
                <div class="header card-petition-title">
                    <a href="' . esc_url($link) . '" data-bjax>' . esc_html($title) . '</a>
                </div>
                <div class="description">
                    <p>' . esc_html($excerpt) . '</p>
                </div>
            </div>
            <div class="extra content">';
            $return_string .= conikal_give_donation_progress($form_id);
            if ($column == 'three') {
                $return_string .= '<span class="right floated">';
                $return_string .= '<a href="' . esc_url($author_url) . '" data-bjax>';
                $return_string .= '<img class="ui avatar image supporter-avatar lazy" data-src="' . esc_url($avatar) . '" data-retina="' . esc_url($avatar_retina) . '" src="' . esc_url($lazy_placeholder_avatar) . '" alt="' . esc_attr($author_name) . '" data-title="' . esc_attr($author_name) . '" data-content="';
                if ($user_country || $user_state || $user_city) {
                    $return_string .= ($user_city ? esc_attr($user_city) . ', ' : '') . ($user_state ? esc_attr($user_state) . ', ' : '') . ($user_country ? esc_attr($user_country) : '');
                }
                $return_string .= '"/>';
                $return_string .= '</a>';
                $return_string .= '</span>';
            }
                $return_string .= '<span class="ui primary label">' . (empty($backers) ? esc_html__('No Backer', 'campoal-tapo') : conikal_custom_icon('supporter') . sprintf(_n('%s backer', '%s backers', $backers, 'campoal-tapo'), conikal_format_number('%!,0i', $backers, true)) ) . '</span>';
                if($comments->approved != 0) {
                    $return_string .= '<span class="ui label"><i class="comments icon"></i>' . conikal_format_number('%!,0i', $comments->approved, true) . '</span>';
                }
                $return_string .= '</div>
        </div>';
        if ( conikal_carousel_mode($carousel) == 0 ) {
            
        } else {
            $return_string .= '</div>';
        }

        // echo $return_string;

        return $return_string;
    }
endif;

?>