<?php

/**
 * Petition list content in shortcode
 */
if (!function_exists('conikal_shortcode_petition_card')) :
    function conikal_shortcode_petition_card($petition, $attrs, $content = null) {
        // convert petition data array to variables
        extract($petition);

        // convert shortcode attributes to variables
        extract(shortcode_atts(array(
            'title' => 'Recent petitions',
            'show' => '4',
            'category' => '',
            'style' => 'grid',
            'carousel' => 'no',
            'column' => 'four',
            'hover' => false,
        ), $attrs));

        // lazy load placeholder
        $lazy_placeholder_avatar = conikal_lazy_load_placeholder('avatar');

        $return_string = '';
    	if ( conikal_carousel_mode($carousel) == 0) {
            $return_string .= '<div class="card petition-card' . esc_attr($hover == true ? ' active-hover' : '') . '">';
        } else {
            $return_string .= '<div>';
            $return_string .= '<div class="ui fluid card petition-card' . esc_attr($hover == true ? ' active-hover' : '') . '" style="margin-bottom: 2px;">';
        }
        if ($sign >= $goal || $status == '1') {
            $return_string .= '<div class="ui primary right corner large label victory-label"><i class="flag icon"></i></div>';
        }
        if ($thumbnail) {
            $return_string .= '<a href="' . esc_url($link) . '" class="image" target="' . ($external_link != 0 ? esc_attr('_blank') : esc_attr('_self')) . '" ' . ($external_link != 0 ? '' : esc_attr('data-bjax')) . '>';
            $return_string .= '<div class="ui dimmer"><div class="content">';
            $return_string .= '<div class="center"><div class="ui icon inverted circular ' . ($column == 'three' ? 'big ' : '') . 'button"><i class="external alternate icon"></i></div></div>';
            if ($country || $state || $city) { 
                $return_string .= '<div class="petition-location"><i class="map marker icon"></i>' . ($city && $column == 'three' ? esc_html($city) . ', ' : '') . ($state ? esc_html($state) . ', ' : '') . ($country ? esc_html($country) : '') . '</div>';
            }
            if ($view_counter == 1) {
                $return_string .= '<div class="view-counter"><i class="eye icon"></i>' . esc_html($view) . '</div>';
            }
            $return_string .= '</div></div>';
            $return_string .= '<img class="ui fluid image lazy" data-src="' . esc_url($thumbnail) . '" data-retina="' . esc_url($thumbnail_retina) . '" src="' . esc_url($lazy_placeholder) . '" alt="' . esc_attr($petition_title) . '">';
            $return_string .= '</a>';
        }
        $return_string .= '<div class="content petition-content">';
        if ($column == 'three' || $column == 'four') {
            $return_string .= '<div class="meta">';
            $return_string .= '<span class="receiver truncate petition-to">' . conikal_custom_icon('send') . ' ' . sprintf(esc_html__('Petition to %s', 'campoal-tapo'), esc_html($receiver)) . '</span>';
            $return_string .= '</div>';
        }
        $return_string .= '<div class="header card-petition-title ' . esc_attr(!$thumbnail ? 'no-thumbnail' : '') . '"><a href="' . esc_url($link) . '" data-bjax>' . esc_attr($petition_title) . '</a></div>';
        if (!$thumbnail) {
            $return_string .= '<div class="description">';
            $return_string .= '<div class="text grey">' . esc_html($excerpt_long) . '</div>';
            $return_string .= '</div>';
        }
        if ($column != 'three') {
            $return_string .= '<div class="meta">';
            $return_string .= esc_html__('by', 'campoal-tapo') . ' ' . '<a href="' . get_author_posts_url( $author_id ) . '" data-bjax>' . get_the_author_meta( 'display_name' , $author_id ) . '</a>';
            $return_string .= '</div>';
        } elseif ($thumbnail) {
            $return_string .= '<div class="description">';
            $return_string .= '<div class="text grey">' . esc_html($excerpt) . '</div>';
            $return_string .= '</div>';
        }
        if (!$thumbnail) {
            if ($country || $state || $city) { 
                $return_string .= '<div class="meta petition-location"><i class="map marker icon"></i> ' . ($city && $column == 'three' ? esc_html($city) . ', ' : '') . ($state ? esc_html($state) . ', ' : '') . ($country ? esc_html($country) : '') . '</div>';
            }
            if ($view_counter == 1) {
                $return_string .= '<div class="meta view-counter"><i class="eye icon"></i> ' . sprintf( _n('%s view', '%s views', (int) conikal_get_post_views($id), 'campoal-tapo'), $view) . '</div>';
            }
        }
        $return_string .= '</div>';
        $return_string .= '<div class="extra content">';
        if ($column == 'three') {
            $return_string .= '<span class="right floated">';
            $return_string .= '<a href="' . esc_url($author_url) . '" data-bjax>';
            $return_string .= '<img class="ui avatar image supporter-avatar lazy" data-src="' . esc_url($avatar) . '" data-retina="' . esc_url($avatar_retina) . '" src="' . esc_url($lazy_placeholder_avatar) . '" alt="' . esc_attr($author_name) . '" data-title="' . esc_attr($author_name) . '" data-content="';
            if ($user_country || $user_state || $user_city) {
                $return_string .= ($user_city ? esc_attr($user_city) . ', ' : '') . ($user_state ? esc_attr($user_state) . ', ' : '') . ($user_country ? esc_attr($user_country) : '');
            }
            $return_string .= '"/>';
            $return_string .= '</a>';
            $return_string .= '</span>';
        }
        $return_string .= '<span class="ui primary label">' . conikal_custom_icon('supporter') . sprintf($supporter_number->label, esc_html(conikal_format_number('%!,0i', $sign, true))) . '</span>';
        if($comments->approved != 0) {
            $return_string .= '<span class="ui label"><i class="comments icon"></i>' . conikal_format_number('%!,0i', $comments->approved, true) . '</span>';
        }
        $return_string .= '</div>';
        $return_string .= '<div class="ui bottom attached indicating primary progress petition-goal" data-value="' . esc_attr($sign) . '" data-total="' . esc_attr($goal) . '">';
        $return_string .= '<div class="bar"><div class="progress"></div></div>';
        $return_string .= '</div>';
        $return_string .= '</div>';

        if ( conikal_carousel_mode($carousel) == 0) {
            
        } else {
            $return_string .= '</div>';
        }

        return $return_string;
    }
endif;

?>